==> multiphasepy-1.0.0.tar.gz: multiphasepy-1.0.0/tests/test_rodare.py <==
# This file is part of the Multiphase Python Repository by HZDR.
#
# Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
# Website: https://hzdr.de
#
# Multiphase Python Repository by HZDR is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Multiphase Python Repository by HZDR is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with the Multiphase Python Repository by HZDR. If not, see
# <http://www.gnu.org/licenses/>.

"""Test module for rodare functionality."""

from multiphasepy import rodare
from unittest.mock import patch
import requests_mock
import json
import yaml
from datetime import date


@patch("multiphasepy.rodare.date")
def test_codemeta2rodare(mock_date):
    """Test codemeta conversion to rodare."""
    mock_date.today.return_value = date(2024, 1, 1)
    mock_date.side_effect = lambda *args, **kw: date(*args, **kw)

    with open("tests/data/rodare/codemeta.json", "r", encoding="utf8") as f:
        codemeta_schema = json.load(f)

    rodare_data = rodare.codemeta2rodare(codemeta_schema, "1")
    assert rodare_data == {
        "metadata": {
            "communities": [
                {"identifier": "energy"},
                {"identifier": "fwd"},
                {"identifier": "rodare"},
                {"identifier": "hzdr"},
                {"identifier": "openfoam"},
            ],
            "contributors": [
                {
                    "affiliation": "Helmholtz-Zentrum Dresden-Rossendorf",
                    "name": "Doe, John",
                    "type": "Other",
                }
            ],
            "creators": [
                {
                    "affiliation": "Helmholtz-Zentrum Dresden-Rossendorf",
                    "name": "Doe, Jane",
                    "orcid": "0000-0001-0002-0003",
                }
            ],
            "description": "<p>This is a great software.</p>",
            "doc_id": "1",
            "keywords": ["Banana", "Apple", "Cherry", "C++", "C", "CUDA"],
            "language": "eng",
            "license": "GPL-3.0-or-later",
            "pub_id": "1",
            "publication_date": "2024-01-01",
            "references": [
                "Doe, J., (2024). My paper. Journal for Something, 1(1), 1-10."
            ],
            "title": "My great software",
            "upload_type": "software",
            "version": "1.0.0",
        },
    }


@patch("multiphasepy.rodare.date")
def test_citationcff2rodare(mock_date):
    """Test CITATION.cff conversion to rodare."""
    mock_date.today.return_value = date(2024, 1, 1)
    mock_date.side_effect = lambda *args, **kw: date(*args, **kw)

    with open("tests/data/rodare/CITATION.cff", "r", encoding="utf8") as f:
        codemeta_schema = yaml.safe_load(f)

    rodare_data = rodare.citationcff2rodare(codemeta_schema, "1")

    assert rodare_data == {
        "metadata": {
            "title": "My great software",
            "upload_type": "software",
            "description": "<p>This is a great software.</p>",
            "language": "eng",
            "license": "GPL-3.0-or-later",
            "doc_id": "1",
            "pub_id": "1",
            "publication_date": "2024-01-01",
            "keywords": ["Banana", "Apple", "Cherry", "C++", "C", "CUDA"],
            "version": "1.0.0",
            "creators": [
                {
                    "affiliation": "Helmholtz-Zentrum Dresden-Rossendorf",
                    "name": "Doe, Jane",
                    "orcid": "0000-0001-0002-0003",
                }
            ],
            "references": [
                "Doe, J., (2024). My paper. Journal for Something, 1(1), 1-10."
            ],
        }
    }


def test_publish_version():
    """Test interaction with Rodare via requests."""
    metadata = {
        "metadata": {
            "title": "My great software",
            "upload_type": "software",
            "description": "<p>This is a great software.</p>",
            "language": "eng",
            "license": "GPL-3.0-or-later",
            "doc_id": "1",
            "pub_id": "1",
            "publication_date": "2024-01-01",
            "keywords": ["Banana", "Apple", "Cherry", "C++", "C", "CUDA"],
            "version": "1.0.0",
            "creators": [
                {
                    "affiliation": "Helmholtz-Zentrum Dresden-Rossendorf",
                    "name": "Doe, Jane",
                    "orcid": "0000-0001-0002-0003",
                }
            ],
            "references": [
                "Doe, J., (2024). My paper. Journal for Something, 1(1), 1-10."
            ],
            "related_identifiers": [
                {
                    "identifier": "https://www.hzdr.de/publications/Publ-123",
                    "relation": "isIdenticalTo",
                    "scheme": "url",
                }
            ],
        }
    }

    example_response = {
        "files": [],
        "id": 2,
        "links": {
            "bucket": "https://rodare.hzdr.de/api/files/123",
            "files": "https://rodare.hzdr.de/api/deposit/depositions/1/files",
            "latest": "https://rodare.hzdr.de/api/records/1",
            "newversion": "https://rodare.hzdr.de/api/deposit/depositions/1/actions/newversion",
            "publish": "https://rodare.hzdr.de/api/deposit/depositions/1/actions/publish",
            "self": "https://rodare.hzdr.de/api/deposit/depositions/1",
            "latest_draft": "https://rodare.hzdr.de/api/deposit/depositions/2",
        },
        "title": "My great software",
    }

    file_response = [
        {
            "filename": "test.dat",
            "id": "123",
            "links": {
                "download": "https://rodare.hzdr.de/api/files/123/test.dat"
            },
        }
    ]

    with requests_mock.Mocker() as mock:
        mock.get(
            "https://rodare.hzdr.de/api/deposit/depositions/1",
            status_code=200,
            json=example_response,
        )
        mock.get(
            "https://rodare.hzdr.de/api/records/1",
            status_code=200,
            json=example_response,
        )
        mock.get(
            "https://rodare.hzdr.de/api/deposit/depositions/2",
            status_code=200,
            json=example_response,
        )
        mock.get(
            "https://rodare.hzdr.de/api/deposit/depositions/1/files",
            status_code=200,
            json=file_response,
        )
        mock.post(
            "https://rodare.hzdr.de/api/deposit/depositions/1/actions/newversion",
            status_code=201,
            json=example_response,
        )
        mock.post(
            "https://rodare.hzdr.de/api/deposit/depositions/1/actions/publish",
            status_code=202,
            json={},
        )
        mock.delete(
            "https://rodare.hzdr.de/api/files/123/test.dat",
            status_code=204,
            json={},
        )
        mock.put(
            "https://rodare.hzdr.de/api/deposit/depositions/1",
            status_code=200,
            json={},
        )

        rodare.publish_version(
            "https://rodare.hzdr.de/api/deposit/depositions",
            "123",
            1,
            [],
            metadata,
        )
        assert mock.call_count == 8

==> multiphasepy-1.1.2.tar.gz: multiphasepy-1.1.2/tests/test_rodare.py <==
# This file is part of the Multiphase Python Repository by HZDR.
#
# Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
# Website: https://hzdr.de
#
# Multiphase Python Repository by HZDR is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Multiphase Python Repository by HZDR is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with the Multiphase Python Repository by HZDR. If not, see
# <http://www.gnu.org/licenses/>.

"""Test module for rodare functionality."""

from multiphasepy import rodare
from unittest.mock import patch
import requests_mock
import json
import yaml
from datetime import date


@patch("multiphasepy.rodare.date")
def test_codemeta2rodare(mock_date):
    """Test codemeta conversion to rodare."""
    mock_date.today.return_value = date(2024, 1, 1)
    mock_date.side_effect = lambda *args, **kw: date(*args, **kw)

    with open("tests/data/rodare/codemeta.json", "r", encoding="utf8") as f:
        codemeta_schema = json.load(f)

    rodare_data = rodare.codemeta2rodare(codemeta_schema, "1")
    assert rodare_data == {
        "metadata": {
            "communities": [
                {"identifier": "energy"},
                {"identifier": "fwd"},
                {"identifier": "rodare"},
                {"identifier": "hzdr"},
                {"identifier": "openfoam"},
            ],
            "contributors": [
                {
                    "affiliation": "Helmholtz-Zentrum Dresden-Rossendorf",
                    "name": "Doe, John",
                    "type": "Other",
                }
            ],
            "creators": [
                {
                    "affiliation": "Helmholtz-Zentrum Dresden-Rossendorf",
                    "name": "Doe, Jane",
                    "orcid": "0000-0001-0002-0003",
                }
            ],
            "description": "<p>This is a great software.</p>",
            "doc_id": "1",
            "keywords": ["Banana", "Apple", "Cherry", "C++", "C", "CUDA"],
            "language": "eng",
            "license": "GPL-3.0-or-later",
            "pub_id": "1",
            "publication_date": "2024-01-01",
            "references": [
                "Doe, J., (2024). My paper. Journal for Something, 1(1), 1-10."
            ],
            "title": "My great software",
            "upload_type": "software",
            "version": "1.0.0",
        },
    }


@patch("multiphasepy.rodare.date")
def test_citationcff2rodare(mock_date):
    """Test CITATION.cff conversion to rodare."""
    mock_date.today.return_value = date(2024, 1, 1)
    mock_date.side_effect = lambda *args, **kw: date(*args, **kw)

    with open("tests/data/rodare/CITATION.cff", "r", encoding="utf8") as f:
        citationcff_schema = yaml.safe_load(f)

    rodare_data = rodare.citationcff2rodare(citationcff_schema, "1")

    assert rodare_data == {
        "metadata": {
            "title": "My great software",
            "upload_type": "software",
            "description": "<p>This is a great software.</p>",
            "language": "eng",
            "license": "GPL-3.0-or-later",
            "doc_id": "1",
            "pub_id": "1",
            "publication_date": "2024-01-01",
            "keywords": ["Banana", "Apple", "Cherry", "C++", "C", "CUDA"],
            "version": "1.0.0",
            "creators": [
                {
                    "affiliation": "Helmholtz-Zentrum Dresden-Rossendorf",
                    "name": "Doe, Jane",
                    "orcid": "0000-0001-0002-0003",
                }
            ],
            "references": [
                "Doe, J., (2024). My paper. Journal for Something, 1(1), 1-10."
            ],
        }
    }

    citationcff_schema.pop("references")
    rodare_data = rodare.citationcff2rodare(citationcff_schema, "1")
    assert rodare_data == {
        "metadata": {
            "title": "My great software",
            "upload_type": "software",
            "description": "<p>This is a great software.</p>",
            "language": "eng",
            "license": "GPL-3.0-or-later",
            "doc_id": "1",
            "pub_id": "1",
            "publication_date": "2024-01-01",
            "keywords": ["Banana", "Apple", "Cherry", "C++", "C", "CUDA"],
            "version": "1.0.0",
            "creators": [
                {
                    "affiliation": "Helmholtz-Zentrum Dresden-Rossendorf",
                    "name": "Doe, Jane",
                    "orcid": "0000-0001-0002-0003",
                }
            ],
            "references": [],
        }
    }


def test_publish_version():
    """Test interaction with Rodare via requests."""
    metadata = {
        "metadata": {
            "title": "My great software",
            "upload_type": "software",
            "description": "<p>This is a great software.</p>",
            "language": "eng",
            "license": "GPL-3.0-or-later",
            "doc_id": "1",
            "pub_id": "1",
            "publication_date": "2024-01-01",
            "keywords": ["Banana", "Apple", "Cherry", "C++", "C", "CUDA"],
            "version": "1.0.0",
            "creators": [
                {
                    "affiliation": "Helmholtz-Zentrum Dresden-Rossendorf",
                    "name": "Doe, Jane",
                    "orcid": "0000-0001-0002-0003",
                }
            ],
            "references": [
                "Doe, J., (2024). My paper. Journal for Something, 1(1), 1-10."
            ],
            "related_identifiers": [
                {
                    "identifier": "https://www.hzdr.de/publications/Publ-123",
                    "relation": "isIdenticalTo",
                    "scheme": "url",
                }
            ],
        }
    }

    example_response = {
        "files": [],
        "id": 2,
        "links": {
            "bucket": "https://rodare.hzdr.de/api/files/123",
            "files": "https://rodare.hzdr.de/api/deposit/depositions/1/files",
            "latest": "https://rodare.hzdr.de/api/records/1",
            "newversion": "https://rodare.hzdr.de/api/deposit/depositions/1/actions/newversion",
            "publish": "https://rodare.hzdr.de/api/deposit/depositions/1/actions/publish",
            "self": "https://rodare.hzdr.de/api/deposit/depositions/1",
            "latest_draft": "https://rodare.hzdr.de/api/deposit/depositions/2",
        },
        "title": "My great software",
    }

    file_response = [
        {
            "filename": "test.dat",
            "id": "123",
            "links": {
                "download": "https://rodare.hzdr.de/api/files/123/test.dat"
            },
        }
    ]

    with requests_mock.Mocker() as mock:
        mock.get(
            "https://rodare.hzdr.de/api/deposit/depositions/1",
            status_code=200,
            json=example_response,
        )
        mock.get(
            "https://rodare.hzdr.de/api/records/1",
            status_code=200,
            json=example_response,
        )
        mock.get(
            "https://rodare.hzdr.de/api/deposit/depositions/2",
            status_code=200,
            json=example_response,
        )
        mock.get(
            "https://rodare.hzdr.de/api/deposit/depositions/1/files",
            status_code=200,
            json=file_response,
        )
        mock.post(
            "https://rodare.hzdr.de/api/deposit/depositions/1/actions/newversion",
            status_code=201,
            json=example_response,
        )
        mock.post(
            "https://rodare.hzdr.de/api/deposit/depositions/1/actions/publish",
            status_code=202,
            json={},
        )
        mock.delete(
            "https://rodare.hzdr.de/api/files/123/test.dat",
            status_code=204,
            json={},
        )
        mock.put(
            "https://rodare.hzdr.de/api/deposit/depositions/1",
            status_code=200,
            json={},
        )

        rodare.publish_version(
            "https://rodare.hzdr.de/api/deposit/depositions",
            "123",
            1,
            [],
            metadata,
        )
        assert mock.call_count == 8
